# API Reference

Documentation for decorators and utility functions.

## monitoring.py

- `Timer`
- `ErrorCatcher`
- `get_metrics_start`
- `get_metrics_end`

## analysis.py

- `analysis(args)`
- `generate_plots(df, output_dir, subtitle)`
